Crate openvr

Crate openvr 

Modules

application
button_id
chaperone
compositor
The Compositor implements distortion, prediction, synchronization and other subtle issues that can be a challenge to get operating properly for a solid VR experience.
errors
input
overlay
pose
property
render_models
settings
system
The System interface provides access to display configuration information, tracking data, controller state, events, and device properties. It is the main interface of OpenVR.
tracked_device_index

Structs

Application
Chaperone
ColorTint
Tints each color channel by multiplying it with the given f32
Compositor
Context
Entry points into OpenVR.
ControllerAxis
ControllerState
Input
Overlay
RenderModels
Settings
System
TextureBounds
TrackedDeviceIndex
TrackedDevicePose
TrackedDeviceProperty
VkDevice_T
VkInstance_T
VkPhysicalDevice_T
VkQueue_T

Enums

ApplicationType
Eye
InitError
TrackedControllerRole
TrackedDeviceClass
TrackingResult
TrackingUniverseOrigin

Constants

MAX_TRACKED_DEVICE_COUNT

Functions

init
Initialize OpenVR
is_hmd_present
is_runtime_installed

Type Aliases

TrackedDevicePoses