Overlay

Struct Overlay 

pub struct Overlay(/* private fields */);

Implementations

Source

impl Overlay

pub fn create_overlay( &mut self, key: &str, friendly_name: &str, ) -> Result<OverlayHandle, VROverlayError>

pub fn set_visibility( &mut self, overlay: OverlayHandle, is_visible: bool, ) -> Result<(), VROverlayError>

pub fn is_visible(&mut self, overlay: OverlayHandle) -> bool

pub fn set_curvature( &mut self, overlay: OverlayHandle, curvature: f32, ) -> Result<(), VROverlayError>

Set the curvature of the overlay, with 0 being a quad and 1 being a cylinder.

Panics

Panics if curvature is not in [0,1]

pub fn curvature( &mut self, overlay: OverlayHandle, ) -> Result<f32, VROverlayError>

pub fn set_opacity( &mut self, overlay: OverlayHandle, alpha: f32, ) -> Result<(), VROverlayError>

Sets the opacity of the overlay. alpha ranges from 0.0 (transparent) to 1.0 (opaque).

Panics

Panics if alpha is not in [0,1]

pub fn opacity(&mut self, overlay: OverlayHandle) -> Result<f32, VROverlayError>

pub fn width(&mut self, overlay: OverlayHandle) -> Result<f32, VROverlayError>

pub fn set_width( &mut self, overlay: OverlayHandle, width_in_meters: f32, ) -> Result<(), VROverlayError>

pub fn sort_order( &mut self, overlay: OverlayHandle, ) -> Result<u32, VROverlayError>

pub fn set_sort_order( &mut self, overlay: OverlayHandle, sort_order: u32, ) -> Result<(), VROverlayError>

pub fn tint( &mut self, overlay: OverlayHandle, ) -> Result<ColorTint, VROverlayError>

pub fn set_tint( &mut self, overlay: OverlayHandle, tint: ColorTint, ) -> Result<(), VROverlayError>

pub fn set_image( &mut self, overlay: OverlayHandle, img_path: &CStr, ) -> Result<(), VROverlayError>

pub fn set_raw_data( &mut self, overlay: OverlayHandle, data: &[u8], width: usize, height: usize, bytes_per_pixel: usize, ) -> Result<(), VROverlayError>

pub fn texel_aspect( &mut self, overlay: OverlayHandle, ) -> Result<f32, VROverlayError>

Get aspect ratio, with aspect expressed as width / height.

pub fn set_texel_aspect( &mut self, overlay: OverlayHandle, aspect: f32, ) -> Result<(), VROverlayError>

Set aspect ratio, with aspect expressed as width / height.

Note that too extreme of an aspect ratio will cause an error to be returned.

pub fn set_transform_absolute( &mut self, overlay: OverlayHandle, origin: TrackingUniverseOrigin, origin_to_overlay: &Matrix3x4, ) -> Result<(), VROverlayError>

Sets an absolute transform for this overlay.

Wraps c++ SetOverlayTransformAbsolute.

pub fn get_transform_absolute( &mut self, overlay: OverlayHandle, origin_to_overlay: &mut Matrix3x4, ) -> Result<TrackingUniverseOrigin, VROverlayError>

Gets the absolute transform for this overlay.

Wraps c++ GetOverlayTransformAbsolute.

pub fn set_transform_tracked_device_relative( &mut self, overlay: OverlayHandle, index: TrackedDeviceIndex, device_to_overlay: &Matrix3x4, ) -> Result<(), VROverlayError>

Sets the transform for this overlay, relative to a tracked device.

Wraps c++ SetOverlayTransformTrackedDeviceRelative.

pub fn get_transform_tracked_device_relative( &mut self, overlay: OverlayHandle, device_to_overlay: &mut Matrix3x4, ) -> Result<TrackedDeviceIndex, VROverlayError>

Gets the transform for this overlay, relative to a tracked device.

Wraps c++ GetOverlayTransformTrackedDeviceRelative.

pub fn set_texture_bounds( &mut self, overlay: OverlayHandle, bounds: &TextureBounds, ) -> Result<(), VROverlayError>

pub fn is_dashboard_visible(&mut self) -> bool